#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .relaxation_bounding_method import relaxation_bounding_method as relaxation_bounding_method_cls
from .default_min_max_relaxation_limits import default_min_max_relaxation_limits as default_min_max_relaxation_limits_cls
from .minimum_allowed_effctive_relaxation import minimum_allowed_effctive_relaxation as minimum_allowed_effctive_relaxation_cls
from .maximum_allowed_effctive_relaxation import maximum_allowed_effctive_relaxation as maximum_allowed_effctive_relaxation_cls

class relaxation_bounds(Command):
    """
    Select relaxation bounding scheme for pseudo time method.
    
    Parameters
    ----------
        relaxation_bounding_method : str
            'relaxation_bounding_method' child.
        default_min_max_relaxation_limits : bool
            'default_min_max_relaxation_limits' child.
        minimum_allowed_effctive_relaxation : real
            'minimum_allowed_effctive_relaxation' child.
        maximum_allowed_effctive_relaxation : real
            'maximum_allowed_effctive_relaxation' child.
    
    """

    fluent_name = "relaxation-bounds"

    argument_names = \
        ['relaxation_bounding_method', 'default_min_max_relaxation_limits',
         'minimum_allowed_effctive_relaxation',
         'maximum_allowed_effctive_relaxation']

    _child_classes = dict(
        relaxation_bounding_method=relaxation_bounding_method_cls,
        default_min_max_relaxation_limits=default_min_max_relaxation_limits_cls,
        minimum_allowed_effctive_relaxation=minimum_allowed_effctive_relaxation_cls,
        maximum_allowed_effctive_relaxation=maximum_allowed_effctive_relaxation_cls,
    )

    return_type = "<object object at 0x7fc5542405c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .axis import axis as axis_cls
from .degassing import degassing as degassing_cls
from .exhaust_fan import exhaust_fan as exhaust_fan_cls
from .fan import fan as fan_cls
from .geometry_2 import geometry as geometry_cls
from .inlet_vent import inlet_vent as inlet_vent_cls
from .intake_fan import intake_fan as intake_fan_cls
from .interface import interface as interface_cls
from .interior import interior as interior_cls
from .mass_flow_inlet import mass_flow_inlet as mass_flow_inlet_cls
from .mass_flow_outlet import mass_flow_outlet as mass_flow_outlet_cls
from .network import network as network_cls
from .network_end import network_end as network_end_cls
from .outflow import outflow as outflow_cls
from .outlet_vent import outlet_vent as outlet_vent_cls
from .overset import overset as overset_cls
from .periodic import periodic as periodic_cls
from .porous_jump import porous_jump as porous_jump_cls
from .pressure_far_field import pressure_far_field as pressure_far_field_cls
from .pressure_inlet import pressure_inlet as pressure_inlet_cls
from .pressure_outlet import pressure_outlet as pressure_outlet_cls
from .radiator import radiator as radiator_cls
from .rans_les_interface import rans_les_interface as rans_les_interface_cls
from .recirculation_inlet import recirculation_inlet as recirculation_inlet_cls
from .recirculation_outlet import recirculation_outlet as recirculation_outlet_cls
from .shadow import shadow as shadow_cls
from .symmetry import symmetry as symmetry_cls
from .velocity_inlet import velocity_inlet as velocity_inlet_cls
from .wall import wall as wall_cls
from .change_type import change_type as change_type_cls
from .slit_face_zone import slit_face_zone as slit_face_zone_cls
from .slit_interior_between_diff_solids import slit_interior_between_diff_solids as slit_interior_between_diff_solids_cls
from .create_all_shell_threads import create_all_shell_threads as create_all_shell_threads_cls
from .recreate_all_shells import recreate_all_shells as recreate_all_shells_cls
from .delete_all_shells import delete_all_shells as delete_all_shells_cls
from .orient_face_zone import orient_face_zone as orient_face_zone_cls

class boundary_conditions(Group, _ChildNamedObjectAccessorMixin):
    """
    'boundary_conditions' child.
    """

    fluent_name = "boundary-conditions"

    child_names = \
        ['axis', 'degassing', 'exhaust_fan', 'fan', 'geometry', 'inlet_vent',
         'intake_fan', 'interface', 'interior', 'mass_flow_inlet',
         'mass_flow_outlet', 'network', 'network_end', 'outflow',
         'outlet_vent', 'overset', 'periodic', 'porous_jump',
         'pressure_far_field', 'pressure_inlet', 'pressure_outlet',
         'radiator', 'rans_les_interface', 'recirculation_inlet',
         'recirculation_outlet', 'shadow', 'symmetry', 'velocity_inlet',
         'wall']

    command_names = \
        ['change_type', 'slit_face_zone', 'slit_interior_between_diff_solids',
         'create_all_shell_threads', 'recreate_all_shells',
         'delete_all_shells', 'orient_face_zone']

    _child_classes = dict(
        axis=axis_cls,
        degassing=degassing_cls,
        exhaust_fan=exhaust_fan_cls,
        fan=fan_cls,
        geometry=geometry_cls,
        inlet_vent=inlet_vent_cls,
        intake_fan=intake_fan_cls,
        interface=interface_cls,
        interior=interior_cls,
        mass_flow_inlet=mass_flow_inlet_cls,
        mass_flow_outlet=mass_flow_outlet_cls,
        network=network_cls,
        network_end=network_end_cls,
        outflow=outflow_cls,
        outlet_vent=outlet_vent_cls,
        overset=overset_cls,
        periodic=periodic_cls,
        porous_jump=porous_jump_cls,
        pressure_far_field=pressure_far_field_cls,
        pressure_inlet=pressure_inlet_cls,
        pressure_outlet=pressure_outlet_cls,
        radiator=radiator_cls,
        rans_les_interface=rans_les_interface_cls,
        recirculation_inlet=recirculation_inlet_cls,
        recirculation_outlet=recirculation_outlet_cls,
        shadow=shadow_cls,
        symmetry=symmetry_cls,
        velocity_inlet=velocity_inlet_cls,
        wall=wall_cls,
        change_type=change_type_cls,
        slit_face_zone=slit_face_zone_cls,
        slit_interior_between_diff_solids=slit_interior_between_diff_solids_cls,
        create_all_shell_threads=create_all_shell_threads_cls,
        recreate_all_shells=recreate_all_shells_cls,
        delete_all_shells=delete_all_shells_cls,
        orient_face_zone=orient_face_zone_cls,
    )

    return_type = "<object object at 0x7fc55434e990>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .blade_flapping_cone import blade_flapping_cone as blade_flapping_cone_cls
from .blade_flapping_cyclic_sin import blade_flapping_cyclic_sin as blade_flapping_cyclic_sin_cls
from .blade_flapping_cyclic_cos import blade_flapping_cyclic_cos as blade_flapping_cyclic_cos_cls

class blade_flap_angles(Group):
    """
    Menu to define the rotor pitch angles.
    
     - blade-flapping-cone       : , 
     - blade-flapping-cyclic-sin : , 
     - blade-flapping-cyclic-cos : , 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "blade-flap-angles"

    child_names = \
        ['blade_flapping_cone', 'blade_flapping_cyclic_sin',
         'blade_flapping_cyclic_cos']

    _child_classes = dict(
        blade_flapping_cone=blade_flapping_cone_cls,
        blade_flapping_cyclic_sin=blade_flapping_cyclic_sin_cls,
        blade_flapping_cyclic_cos=blade_flapping_cyclic_cos_cls,
    )

    return_type = "<object object at 0x7fc5c18a4dd0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .flux import flux as flux_cls
from .gradient import gradient as gradient_cls

class anisotropic_solid_heat_transfer(Group):
    fluent_name = ...
    child_names = ...
    flux: flux_cls = ...
    gradient: gradient_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name_2 import name as name_cls
from .is_not_a_rans_les_interface import is_not_a_rans_les_interface as is_not_a_rans_les_interface_cls

class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'is_not_a_rans_les_interface']

    _child_classes = dict(
        name=name_cls,
        is_not_a_rans_les_interface=is_not_a_rans_les_interface_cls,
    )

    return_type = "<object object at 0x7fb634287cc0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .reset_color import reset_color as reset_color_cls

class reset(Command):
    """
    To reset colors and/or materials to the defaults.
    
    Parameters
    ----------
        reset_color : bool
            'reset_color' child.
    
    """

    fluent_name = "reset?"

    argument_names = \
        ['reset_color']

    _child_classes = dict(
        reset_color=reset_color_cls,
    )

    return_type = "<object object at 0x7fc55413dd70>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .ecad_name import ecad_name as ecad_name_cls
from .choice import choice as choice_cls
from .rows import rows as rows_cls
from .columns import columns as columns_cls
from .ref_frame import ref_frame as ref_frame_cls
from .pwr_names import pwr_names as pwr_names_cls

class pcb_zone_info(Group):
    fluent_name = ...
    child_names = ...
    ecad_name: ecad_name_cls = ...
    choice: choice_cls = ...
    rows: rows_cls = ...
    columns: columns_cls = ...
    ref_frame: ref_frame_cls = ...
    pwr_names: pwr_names_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enabled_12 import enabled as enabled_cls
from .solution_method_1 import solution_method as solution_method_cls
from .echem_model import echem_model as echem_model_cls
from .zone_assignment_1 import zone_assignment as zone_assignment_cls
from .contact_resistance import contact_resistance as contact_resistance_cls
from .ntgk_model_settings import ntgk_model_settings as ntgk_model_settings_cls
from .ecm_model_settings import ecm_model_settings as ecm_model_settings_cls
from .p2d_model_settings import p2d_model_settings as p2d_model_settings_cls
from .eload_condition import eload_condition as eload_condition_cls
from .echem_stop_criterion import echem_stop_criterion as echem_stop_criterion_cls
from .cell_clustering import cell_clustering as cell_clustering_cls
from .solution_option import solution_option as solution_option_cls
from .life_model import life_model as life_model_cls
from .swelling_model import swelling_model as swelling_model_cls
from .thermal_abuse_model import thermal_abuse_model as thermal_abuse_model_cls
from .pack_builder import pack_builder as pack_builder_cls
from .rom_tool_kit import rom_tool_kit as rom_tool_kit_cls
from .orthotropic_k import orthotropic_k as orthotropic_k_cls
from .udf_hooks import udf_hooks as udf_hooks_cls
from .parameter_estimation_tool import parameter_estimation_tool as parameter_estimation_tool_cls
from .standalone_echem_model import standalone_echem_model as standalone_echem_model_cls

class battery(Group):
    fluent_name = ...
    child_names = ...
    enabled: enabled_cls = ...
    solution_method: solution_method_cls = ...
    echem_model: echem_model_cls = ...
    zone_assignment: zone_assignment_cls = ...
    contact_resistance: contact_resistance_cls = ...
    ntgk_model_settings: ntgk_model_settings_cls = ...
    ecm_model_settings: ecm_model_settings_cls = ...
    p2d_model_settings: p2d_model_settings_cls = ...
    eload_condition: eload_condition_cls = ...
    echem_stop_criterion: echem_stop_criterion_cls = ...
    cell_clustering: cell_clustering_cls = ...
    solution_option: solution_option_cls = ...
    life_model: life_model_cls = ...
    swelling_model: swelling_model_cls = ...
    thermal_abuse_model: thermal_abuse_model_cls = ...
    pack_builder: pack_builder_cls = ...
    rom_tool_kit: rom_tool_kit_cls = ...
    orthotropic_k: orthotropic_k_cls = ...
    udf_hooks: udf_hooks_cls = ...
    command_names = ...

    def parameter_estimation_tool(self, ):
        """
        'parameter_estimation_tool' command.
        """

    def standalone_echem_model(self, ):
        """
        'standalone_echem_model' command.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .cycle_type import cycle_type as cycle_type_cls
from .termination_criteria import termination_criteria as termination_criteria_cls
from .residual_reduction_tolerance import residual_reduction_tolerance as residual_reduction_tolerance_cls
from .method import method as method_cls
from .stabilization import stabilization as stabilization_cls

class multi_grid_controls_child(Group):
    fluent_name = ...
    child_names = ...
    cycle_type: cycle_type_cls = ...
    termination_criteria: termination_criteria_cls = ...
    residual_reduction_tolerance: residual_reduction_tolerance_cls = ...
    method: method_cls = ...
    stabilization: stabilization_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .value1 import value1 as value1_cls
from .value2 import value2 as value2_cls

class except_in_range(Group):
    """
    'except_in_range' child.
    """

    fluent_name = "except-in-range"

    child_names = \
        ['value1', 'value2']

    _child_classes = dict(
        value1=value1_cls,
        value2=value2_cls,
    )

    return_type = "<object object at 0x7fb5f6197070>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .disk_origin_x import disk_origin_x as disk_origin_x_cls
from .disk_origin_y import disk_origin_y as disk_origin_y_cls
from .disk_origin_z import disk_origin_z as disk_origin_z_cls

class disk_origin(Group):
    fluent_name = ...
    child_names = ...
    disk_origin_x: disk_origin_x_cls = ...
    disk_origin_y: disk_origin_y_cls = ...
    disk_origin_z: disk_origin_z_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_10 import option as option_cls
from .value import value as value_cls
from .piecewise_linear import piecewise_linear as piecewise_linear_cls
from .piecewise_polynomial import piecewise_polynomial as piecewise_polynomial_cls
from .polynomial import polynomial as polynomial_cls
from .nasa_9_piecewise_polynomial import nasa_9_piecewise_polynomial as nasa_9_piecewise_polynomial_cls
from .real_gas_nist_mixture import real_gas_nist_mixture as real_gas_nist_mixture_cls
from .user_defined_function import user_defined_function as user_defined_function_cls

class specific_heat(Group):
    """
    'specific_heat' child.
    """

    fluent_name = "specific-heat"

    child_names = \
        ['option', 'value', 'piecewise_linear', 'piecewise_polynomial',
         'polynomial', 'nasa_9_piecewise_polynomial', 'real_gas_nist_mixture',
         'user_defined_function']

    _child_classes = dict(
        option=option_cls,
        value=value_cls,
        piecewise_linear=piecewise_linear_cls,
        piecewise_polynomial=piecewise_polynomial_cls,
        polynomial=polynomial_cls,
        nasa_9_piecewise_polynomial=nasa_9_piecewise_polynomial_cls,
        real_gas_nist_mixture=real_gas_nist_mixture_cls,
        user_defined_function=user_defined_function_cls,
    )

    return_type = "<object object at 0x7fc554c48fa0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class accumulated_mass_fraction(Boolean, AllowedValuesMixin):
    """
    'accumulated_mass_fraction' child.
    """

    fluent_name = "accumulated-mass-fraction?"

    return_type = "<object object at 0x7fb66c2e11c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .number_of_represented_species import number_of_represented_species as number_of_represented_species_cls
from .full_mechanism_material_name import full_mechanism_material_name as full_mechanism_material_name_cls
from .fuel_oxidizer_species import fuel_oxidizer_species as fuel_oxidizer_species_cls

class dimension_reduction_mixture_options(Group):
    fluent_name = ...
    child_names = ...
    number_of_represented_species: number_of_represented_species_cls = ...
    full_mechanism_material_name: full_mechanism_material_name_cls = ...
    fuel_oxidizer_species: fuel_oxidizer_species_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .draw_mesh import draw_mesh as draw_mesh_cls
from .filled import filled as filled_cls
from .marker import marker as marker_cls
from .marker_symbol import marker_symbol as marker_symbol_cls
from .marker_size import marker_size as marker_size_cls
from .wireframe import wireframe as wireframe_cls
from .color import color as color_cls

class display_options(Group):
    """
    'display_options' child.
    """

    fluent_name = "display-options"

    child_names = \
        ['draw_mesh', 'filled', 'marker', 'marker_symbol', 'marker_size',
         'wireframe', 'color']

    _child_classes = dict(
        draw_mesh=draw_mesh_cls,
        filled=filled_cls,
        marker=marker_cls,
        marker_symbol=marker_symbol_cls,
        marker_size=marker_size_cls,
        wireframe=wireframe_cls,
        color=color_cls,
    )

    return_type = "<object object at 0x7fb5f61975c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .coupling import coupling as coupling_cls
from .helper_session_setup import helper_session_setup as helper_session_setup_cls
from .helper_session import helper_session as helper_session_cls

class set(Group):
    fluent_name = ...
    child_names = ...
    coupling: coupling_cls = ...
    helper_session_setup: helper_session_setup_cls = ...
    helper_session: helper_session_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .clip_to_range import clip_to_range as clip_to_range_cls
from .minimum_1 import minimum as minimum_cls
from .maximum_1 import maximum as maximum_cls

class auto_range_off(Group):
    fluent_name = ...
    child_names = ...
    clip_to_range: clip_to_range_cls = ...
    minimum: minimum_cls = ...
    maximum: maximum_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .option_4 import option as option_cls
from .tolerance import tolerance as tolerance_cls
from .max_number_of_refinements import max_number_of_refinements as max_number_of_refinements_cls
from .number_of_cells_to_cross import number_of_cells_to_cross as number_of_cells_to_cross_cls

class accuracy_control(Group):
    fluent_name = ...
    child_names = ...
    option: option_cls = ...
    tolerance: tolerance_cls = ...
    max_number_of_refinements: max_number_of_refinements_cls = ...
    number_of_cells_to_cross: number_of_cells_to_cross_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .project_filename import project_filename as project_filename_cls
from .load_case import load_case as load_case_cls

class open(Command):
    """
    Open project.
    
    Parameters
    ----------
        project_filename : str
            'project_filename' child.
        load_case : bool
            'load_case' child.
    
    """

    fluent_name = "open"

    argument_names = \
        ['project_filename', 'load_case']

    _child_classes = dict(
        project_filename=project_filename_cls,
        load_case=load_case_cls,
    )

    return_type = "<object object at 0x7fc5c18a69c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .particle_type import particle_type as particle_type_cls
from .material import material as material_cls
from .reference_frame import reference_frame as reference_frame_cls
from .number_of_streams import number_of_streams as number_of_streams_cls
from .injection_type import injection_type as injection_type_cls
from .interaction_1 import interaction as interaction_cls
from .parcel_method import parcel_method as parcel_method_cls
from .particle_reinjector import particle_reinjector as particle_reinjector_cls
from .physical_models import physical_models as physical_models_cls
from .initial_props import initial_props as initial_props_cls

class injections_child(Group):
    """
    'child_object_type' of injections.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['particle_type', 'material', 'reference_frame', 'number_of_streams',
         'injection_type', 'interaction', 'parcel_method',
         'particle_reinjector', 'physical_models', 'initial_props']

    _child_classes = dict(
        particle_type=particle_type_cls,
        material=material_cls,
        reference_frame=reference_frame_cls,
        number_of_streams=number_of_streams_cls,
        injection_type=injection_type_cls,
        interaction=interaction_cls,
        parcel_method=parcel_method_cls,
        particle_reinjector=particle_reinjector_cls,
        physical_models=physical_models_cls,
        initial_props=initial_props_cls,
    )

    return_type = "<object object at 0x7fc5c18a60b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .chemistry_iterations import chemistry_iterations as chemistry_iterations_cls
from .aggresiveness_factor import aggresiveness_factor as aggresiveness_factor_cls
from .transport_time_scale_factor import transport_time_scale_factor as transport_time_scale_factor_cls
from .min_temperature import min_temperature as min_temperature_cls

class turb_chem_interaction_model_options(Group):
    """
    'turb_chem_interaction_model_options' child.
    """

    fluent_name = "turb-chem-interaction-model-options"

    child_names = \
        ['chemistry_iterations', 'aggresiveness_factor',
         'transport_time_scale_factor', 'min_temperature']

    _child_classes = dict(
        chemistry_iterations=chemistry_iterations_cls,
        aggresiveness_factor=aggresiveness_factor_cls,
        transport_time_scale_factor=transport_time_scale_factor_cls,
        min_temperature=min_temperature_cls,
    )

    return_type = "<object object at 0x7fb66c2e00e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .type_1 import type as type_cls
from .name_1 import name as name_cls

class copy_by_name(Command):
    """
    Copy a material from the database (pick by name).
    
    Parameters
    ----------
        type : str
            'type' child.
        name : str
            'name' child.
    
    """

    fluent_name = "copy-by-name"

    argument_names = \
        ['type', 'name']

    _child_classes = dict(
        type=type_cls,
        name=name_cls,
    )

    return_type = "<object object at 0x7fc5785e80f0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .phase_21 import phase as phase_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .pid import pid as pid_cls
from .temperature_spec import temperature_spec as temperature_spec_cls
from .temperature_rise import temperature_rise as temperature_rise_cls
from .heat_source import heat_source as heat_source_cls
from .tinf import tinf as tinf_cls
from .hc import hc as hc_cls
from .direction_spec import direction_spec as direction_spec_cls
from .coordinate_system import coordinate_system as coordinate_system_cls
from .flow_direction_component import flow_direction_component as flow_direction_component_cls
from .direction_vector_components import direction_vector_components as direction_vector_components_cls
from .ke_spec import ke_spec as ke_spec_cls
from .nut import nut as nut_cls
from .kl import kl as kl_cls
from .intermit import intermit as intermit_cls
from .k import k as k_cls
from .e import e as e_cls
from .o import o as o_cls
from .v2 import v2 as v2_cls
from .turb_intensity import turb_intensity as turb_intensity_cls
from .turb_length_scale import turb_length_scale as turb_length_scale_cls
from .turb_hydraulic_diam import turb_hydraulic_diam as turb_hydraulic_diam_cls
from .turb_viscosity_ratio import turb_viscosity_ratio as turb_viscosity_ratio_cls
from .turb_viscosity_ratio_profile import turb_viscosity_ratio_profile as turb_viscosity_ratio_profile_cls
from .rst_spec import rst_spec as rst_spec_cls
from .uu import uu as uu_cls
from .vv import vv as vv_cls
from .ww import ww as ww_cls
from .uv import uv as uv_cls
from .vw import vw as vw_cls
from .uw import uw as uw_cls
from .ksgs_spec import ksgs_spec as ksgs_spec_cls
from .ksgs import ksgs as ksgs_cls
from .sgs_turb_intensity import sgs_turb_intensity as sgs_turb_intensity_cls
from .mass_flow_multiplier import mass_flow_multiplier as mass_flow_multiplier_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_shining_factor import solar_shining_factor as solar_shining_factor_cls

class recirculation_inlet_child(Group):
    fluent_name = ...
    child_names = ...
    phase: phase_cls = ...
    geom_disable: geom_disable_cls = ...
    geom_dir_spec: geom_dir_spec_cls = ...
    geom_dir_x: geom_dir_x_cls = ...
    geom_dir_y: geom_dir_y_cls = ...
    geom_dir_z: geom_dir_z_cls = ...
    geom_levels: geom_levels_cls = ...
    geom_bgthread: geom_bgthread_cls = ...
    pid: pid_cls = ...
    temperature_spec: temperature_spec_cls = ...
    temperature_rise: temperature_rise_cls = ...
    heat_source: heat_source_cls = ...
    tinf: tinf_cls = ...
    hc: hc_cls = ...
    direction_spec: direction_spec_cls = ...
    coordinate_system: coordinate_system_cls = ...
    flow_direction_component: flow_direction_component_cls = ...
    direction_vector_components: direction_vector_components_cls = ...
    ke_spec: ke_spec_cls = ...
    nut: nut_cls = ...
    kl: kl_cls = ...
    intermit: intermit_cls = ...
    k: k_cls = ...
    e: e_cls = ...
    o: o_cls = ...
    v2: v2_cls = ...
    turb_intensity: turb_intensity_cls = ...
    turb_length_scale: turb_length_scale_cls = ...
    turb_hydraulic_diam: turb_hydraulic_diam_cls = ...
    turb_viscosity_ratio: turb_viscosity_ratio_cls = ...
    turb_viscosity_ratio_profile: turb_viscosity_ratio_profile_cls = ...
    rst_spec: rst_spec_cls = ...
    uu: uu_cls = ...
    vv: vv_cls = ...
    ww: ww_cls = ...
    uv: uv_cls = ...
    vw: vw_cls = ...
    uw: uw_cls = ...
    ksgs_spec: ksgs_spec_cls = ...
    ksgs: ksgs_cls = ...
    sgs_turb_intensity: sgs_turb_intensity_cls = ...
    mass_flow_multiplier: mass_flow_multiplier_cls = ...
    solar_fluxes: solar_fluxes_cls = ...
    solar_shining_factor: solar_shining_factor_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .poisson_ratio_01 import poisson_ratio_01 as poisson_ratio_01_cls
from .poisson_ratio_12 import poisson_ratio_12 as poisson_ratio_12_cls
from .poisson_ratio_02 import poisson_ratio_02 as poisson_ratio_02_cls

class orthotropic_structure_nu(Group):
    """
    'orthotropic_structure_nu' child.
    """

    fluent_name = "orthotropic-structure-nu"

    child_names = \
        ['poisson_ratio_01', 'poisson_ratio_12', 'poisson_ratio_02']

    _child_classes = dict(
        poisson_ratio_01=poisson_ratio_01_cls,
        poisson_ratio_12=poisson_ratio_12_cls,
        poisson_ratio_02=poisson_ratio_02_cls,
    )

    return_type = "<object object at 0x7fb5f6fcf7a0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .reactions_1 import reactions as reactions_cls
from .reaction_source_term_relaxation_factor import reaction_source_term_relaxation_factor as reaction_source_term_relaxation_factor_cls
from .numerics import numerics as numerics_cls
from .numerics_dbns import numerics_dbns as numerics_dbns_cls

class expert(Group):
    fluent_name = ...
    child_names = ...
    reactions: reactions_cls = ...
    reaction_source_term_relaxation_factor: reaction_source_term_relaxation_factor_cls = ...
    numerics: numerics_cls = ...
    numerics_dbns: numerics_dbns_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .distance_option import distance_option as distance_option_cls
from .boundary_list import boundary_list as boundary_list_cls
from .create_volume_surface import create_volume_surface as create_volume_surface_cls

class boundary(Group):
    """
    'boundary' child.
    """

    fluent_name = "boundary"

    child_names = \
        ['distance_option', 'boundary_list', 'create_volume_surface']

    _child_classes = dict(
        distance_option=distance_option_cls,
        boundary_list=boundary_list_cls,
        create_volume_surface=create_volume_surface_cls,
    )

    return_type = "<object object at 0x7f766aaab690>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .cavitation import cavitation as cavitation_cls
from .evaporation_condensation import evaporation_condensation as evaporation_condensation_cls
from .boiling import boiling as boiling_cls
from .area_density_1 import area_density as area_density_cls
from .alternative_energy_treatment import alternative_energy_treatment as alternative_energy_treatment_cls

class heat_mass_transfer(Group):
    """
    Multiphase interphase heat and mass transfer numerics options menu.
    """

    fluent_name = "heat-mass-transfer"

    child_names = \
        ['cavitation', 'evaporation_condensation', 'boiling', 'area_density',
         'alternative_energy_treatment']

    _child_classes = dict(
        cavitation=cavitation_cls,
        evaporation_condensation=evaporation_condensation_cls,
        boiling=boiling_cls,
        area_density=area_density_cls,
        alternative_energy_treatment=alternative_energy_treatment_cls,
    )

    return_type = "<object object at 0x7fc55434fd70>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class preserve_boundary_layer(Integer):
    """
    0 = Decide at runtime.
    1 = Never preserve.
    2 = Always preserve.
    """

    fluent_name = "preserve-boundary-layer"

    return_type = "<object object at 0x7fc5c18a7890>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .heat_flux_relaxation_factor import heat_flux_relaxation_factor as heat_flux_relaxation_factor_cls
from .show_expert_options import show_expert_options as show_expert_options_cls
from .two_resistance_boiling_framework import two_resistance_boiling_framework as two_resistance_boiling_framework_cls

class boiling(Group):
    """
    Boiling advanced options menu.
    """

    fluent_name = "boiling"

    child_names = \
        ['heat_flux_relaxation_factor', 'show_expert_options',
         'two_resistance_boiling_framework']

    _child_classes = dict(
        heat_flux_relaxation_factor=heat_flux_relaxation_factor_cls,
        show_expert_options=show_expert_options_cls,
        two_resistance_boiling_framework=two_resistance_boiling_framework_cls,
    )

    return_type = "<object object at 0x7f766ab83480>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .multi_level_grid import multi_level_grid as multi_level_grid_cls
from .residual_reduction_level import residual_reduction_level as residual_reduction_level_cls
from .cycle_count import cycle_count as cycle_count_cls

class customize_fmg_initialization(Command):
    fluent_name = ...
    argument_names = ...
    multi_level_grid: multi_level_grid_cls = ...
    residual_reduction_level: residual_reduction_level_cls = ...
    cycle_count: cycle_count_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .nist_fluid import nist_fluid as nist_fluid_cls
from .lookup_table import lookup_table as lookup_table_cls
from .pressure_points import pressure_points as pressure_points_cls
from .pressure_minimum import pressure_minimum as pressure_minimum_cls
from .pressure_maximum import pressure_maximum as pressure_maximum_cls
from .temperature_points import temperature_points as temperature_points_cls
from .temperature_minimum import temperature_minimum as temperature_minimum_cls
from .temperature_maximum import temperature_maximum as temperature_maximum_cls
from .saturation_points import saturation_points as saturation_points_cls

class real_gas_nist(Group):
    """
    'real_gas_nist' child.
    """

    fluent_name = "real-gas-nist"

    child_names = \
        ['nist_fluid', 'lookup_table', 'pressure_points', 'pressure_minimum',
         'pressure_maximum', 'temperature_points', 'temperature_minimum',
         'temperature_maximum', 'saturation_points']

    _child_classes = dict(
        nist_fluid=nist_fluid_cls,
        lookup_table=lookup_table_cls,
        pressure_points=pressure_points_cls,
        pressure_minimum=pressure_minimum_cls,
        pressure_maximum=pressure_maximum_cls,
        temperature_points=temperature_points_cls,
        temperature_minimum=temperature_minimum_cls,
        temperature_maximum=temperature_maximum_cls,
        saturation_points=saturation_points_cls,
    )

    return_type = "<object object at 0x7fb66c2e23a0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .courant_number_reduction import courant_number_reduction as courant_number_reduction_cls
from .correction_reduction import correction_reduction as correction_reduction_cls
from .correction_smoothing import correction_smoothing as correction_smoothing_cls
from .species_correction_reduction import species_correction_reduction as species_correction_reduction_cls

class relaxation_factor(Group):
    """
    'relaxation_factor' child.
    """

    fluent_name = "relaxation-factor"

    child_names = \
        ['courant_number_reduction', 'correction_reduction',
         'correction_smoothing', 'species_correction_reduction']

    _child_classes = dict(
        courant_number_reduction=courant_number_reduction_cls,
        correction_reduction=correction_reduction_cls,
        correction_smoothing=correction_smoothing_cls,
        species_correction_reduction=species_correction_reduction_cls,
    )

    return_type = "<object object at 0x7fd82ae38770>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .iter_count_4 import iter_count as iter_count_cls
from .time_steps_count import time_steps_count as time_steps_count_cls
from .fluid_time_step_count import fluid_time_step_count as fluid_time_step_count_cls
from .iter_per_time_step_count import iter_per_time_step_count as iter_per_time_step_count_cls

class dual_time_iterate(Command):
    fluent_name = ...
    argument_names = ...
    iter_count: iter_count_cls = ...
    time_steps_count: time_steps_count_cls = ...
    fluid_time_step_count: fluid_time_step_count_cls = ...
    iter_per_time_step_count: iter_per_time_step_count_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .field import field as field_cls
from .options_7 import options as options_cls
from .enabled_2 import enabled as enabled_cls
from .filter_minimum import filter_minimum as filter_minimum_cls
from .filter_maximum import filter_maximum as filter_maximum_cls

class filter_settings(Group):
    fluent_name = ...
    child_names = ...
    field: field_cls = ...
    options: options_cls = ...
    enabled: enabled_cls = ...
    filter_minimum: filter_minimum_cls = ...
    filter_maximum: filter_maximum_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .min_diam import min_diam as min_diam_cls
from .max_diam import max_diam as max_diam_cls
from .mean_diam import mean_diam as mean_diam_cls
from .spread import spread as spread_cls
from .number_of_diameters import number_of_diameters as number_of_diameters_cls

class rosin_rammler_settings(Group):
    fluent_name = ...
    child_names = ...
    min_diam: min_diam_cls = ...
    max_diam: max_diam_cls = ...
    mean_diam: mean_diam_cls = ...
    spread: spread_cls = ...
    number_of_diameters: number_of_diameters_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .max_vol_mag import max_vol_mag as max_vol_mag_cls
from .vol_frac_cutoff import vol_frac_cutoff as vol_frac_cutoff_cls

class set_velocity_and_vof_cutoffs_child(Group):
    fluent_name = ...
    child_names = ...
    max_vol_mag: max_vol_mag_cls = ...
    vol_frac_cutoff: vol_frac_cutoff_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option import option as option_cls
from .constant import constant as constant_cls
from .boussinesq import boussinesq as boussinesq_cls
from .coefficients import coefficients as coefficients_cls
from .number_of_coefficients import number_of_coefficients as number_of_coefficients_cls
from .piecewise_polynomial import piecewise_polynomial as piecewise_polynomial_cls
from .nasa_9_piecewise_polynomial import nasa_9_piecewise_polynomial as nasa_9_piecewise_polynomial_cls
from .piecewise_linear import piecewise_linear as piecewise_linear_cls
from .anisotropic import anisotropic as anisotropic_cls
from .orthotropic import orthotropic as orthotropic_cls
from .var_class import var_class as var_class_cls

class devolatilization_model(Group):
    """
    'devolatilization_model' child.
    """

    fluent_name = "devolatilization-model"

    child_names = \
        ['option', 'constant', 'boussinesq', 'coefficients',
         'number_of_coefficients', 'piecewise_polynomial',
         'nasa_9_piecewise_polynomial', 'piecewise_linear', 'anisotropic',
         'orthotropic', 'var_class']

    _child_classes = dict(
        option=option_cls,
        constant=constant_cls,
        boussinesq=boussinesq_cls,
        coefficients=coefficients_cls,
        number_of_coefficients=number_of_coefficients_cls,
        piecewise_polynomial=piecewise_polynomial_cls,
        nasa_9_piecewise_polynomial=nasa_9_piecewise_polynomial_cls,
        piecewise_linear=piecewise_linear_cls,
        anisotropic=anisotropic_cls,
        orthotropic=orthotropic_cls,
        var_class=var_class_cls,
    )

    return_type = "<object object at 0x7fd88c7d5c40>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .start import start as start_cls
from .stop import stop as stop_cls
from .print_server_info import print_server_info as print_server_info_cls
from .get_server_info import get_server_info as get_server_info_cls

class web_server(Group):
    fluent_name = ...
    command_names = ...

    def start(self, session_name: str, port: int, port_span: int, job_service_url: str):
        """
        Start the web server.
        
        Parameters
        ----------
            session_name : str
                Name for the web server.
            port : int
                Listening port for the web server.
            port_span : int
                Number of ports to try starting from given 'port' for the web server.
            job_service_url : str
                Job service URL to register Fluent.
        
        """

    def stop(self, ):
        """
        Stop the web server.
        """

    def print_server_info(self, ):
        """
        Print the web server information.
        """

    query_names = ...

    def get_server_info(self, ):
        """
        Get the web server information.
        """

    return_type = ...
